==> yy_core-1.0.0.tar.gz: yy_core-1.0.0/yy_core/models/db_models/refund/refund_order_model.py <==
# -*- coding: utf-8 -*-
"""
@Author: yy
@Date: 2021-09-13 16:26:10
@LastEditTime: 2025-04-23 16:58:26
@LastEditors: yy
@Description: 
"""
#此文件由rigger自动生成
from yy_core.mysql import MySQLHelper
from yy_core.base_model import *
from yy_core.models.cache_model import *


class RefundOrderModel(CacheModel):
    def __init__(self, db_connect_key='db_yy', sub_table=None, db_transaction=None, context=None, is_auto=False):
        super(RefundOrderModel, self).__init__(RefundOrder, sub_table)
        db_connect_key, self.redis_config_dict = CoreHelper.get_connect_config("db_order","redis_order", db_connect_key)
        self.db = MySQLHelper(self.convert_db_config(db_connect_key, is_auto))
        self.db_connect_key = db_connect_key
        self.db_transaction = db_transaction
        self.db.context = context

    #方法扩展请继承此类

class RefundOrder:

    def __init__(self):
        super(RefundOrder, self).__init__()
        self.id = 0  # id
        self.app_id = ""  # 应用标识
        self.act_id = 0  # 活动标识
        self.user_id = 0  # 用户标识
        self.open_id = ""  # open_id
        self.refund_type = 1  # 退款类型（1-手动 2-自动）
        self.pay_order_no = ""  # 支付单号
        self.refund_no = ""  # 退款单号
        self.out_refund_no = ""  # 平台退款单号
        self.out_order_no = ""  # 平台交易单号
        self.refund_amount = 0  # 退款金额
        self.refund_status = 0  # 退款状态 1商户申请退款中2退款处理中3退款成功4退款失败5退款关闭
        self.refund_reason = ""  # 退款理由
        self.refund_date = "1900-01-01 00:00:00"  # 退款时间
        self.refund_result_detail = ""  # 退款结果描述
        self.create_date = "1900-01-01 00:00:00"  # 创建时间

    @classmethod
    def get_field_list(self):
        return ['id', 'app_id', 'act_id', 'user_id', 'open_id', 'refund_type', 'pay_order_no', 'refund_no', 'out_refund_no', 'out_order_no', 'refund_amount', 'refund_status', 'refund_reason', 'refund_date', 'refund_result_detail', 'create_date']

    @classmethod
    def get_primary_key(self):
        return "id"

    def __str__(self):
        return "refund_order_tb"

==> yy_core-1.0.11.tar.gz: yy_core-1.0.11/yy_core/models/db_models/refund/refund_order_model.py <==
# -*- coding: utf-8 -*-
"""
@Author: yy
@Date: 2021-09-13 16:26:10
@LastEditTime: 2025-04-23 16:58:26
@LastEditors: yy
@Description: 
"""
#此文件由rigger自动生成
from yy_core.mysql import MySQLHelper
from yy_core.base_model import *
from yy_core.cache_model import *


class RefundOrderModel(CacheModel):
    def __init__(self, db_connect_key='db_yy', sub_table=None, db_transaction=None, context=None, is_auto=False):
        super(RefundOrderModel, self).__init__(RefundOrder, sub_table)
        db_connect_key, self.redis_config_dict = CoreHelper.get_connect_config("db_order","redis_order", db_connect_key)
        self.db = MySQLHelper(self.convert_db_config(db_connect_key, is_auto))
        self.db_connect_key = db_connect_key
        self.db_transaction = db_transaction
        self.db.context = context

    #方法扩展请继承此类

class RefundOrder:

    def __init__(self):
        super(RefundOrder, self).__init__()
        self.id = 0  # id
        self.app_id = ""  # 应用标识
        self.act_id = 0  # 活动标识
        self.user_id = 0  # 用户标识
        self.open_id = ""  # open_id
        self.refund_type = 1  # 退款类型（1-手动 2-自动）
        self.pay_order_no = ""  # 支付单号
        self.refund_no = ""  # 退款单号
        self.out_refund_no = ""  # 平台退款单号
        self.out_order_no = ""  # 平台交易单号
        self.refund_amount = 0  # 退款金额
        self.refund_status = 0  # 退款状态 1商户申请退款中2退款处理中3退款成功4退款失败5退款关闭
        self.refund_reason = ""  # 退款理由
        self.refund_date = "1900-01-01 00:00:00"  # 退款时间
        self.refund_result_detail = ""  # 退款结果描述
        self.create_date = "1900-01-01 00:00:00"  # 创建时间

    @classmethod
    def get_field_list(self):
        return ['id', 'app_id', 'act_id', 'user_id', 'open_id', 'refund_type', 'pay_order_no', 'refund_no', 'out_refund_no', 'out_order_no', 'refund_amount', 'refund_status', 'refund_reason', 'refund_date', 'refund_result_detail', 'create_date']

    @classmethod
    def get_primary_key(self):
        return "id"

    def __str__(self):
        return "refund_order_tb"
